fnss.netconfig.capacities.set_capacities_random_power_law — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.capacities.set_capacities_random_power_law

`set_capacities_random_power_law`(topology, capacities, capacity_unit='Mbps', reverse=False)

  Set random link capacities according to a power-law probability density function.

  Parameters : | topology : Topology The topology to which link capacities will be set capacities : list A list of all possible capacity values capacity_unit : str, optional The unit in which capacity value is expressed (e.g. Mbps, Gbps etc..) reverse : bool, optional If False, lower capacity links are the most frequent, if True, higher capacity links are more frequent

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »